Module language

Module language 

Modules

go
java
kotlin
python
rust
typescript

Structs

DefaultLanguageRegistry
Concrete implementation of LanguageRegistry backed by the static dispatch tables.
ExtractedCall
A function/method call found in the source
ExtractedImport
Extracted import statement
ExtractedSymbol
Extracted symbol from AST
ExtractedTypeRef
A type reference found in the source (parameter types, return types, field types)
ParseResult
Result of parsing a single file

Traits

LanguageParser
Trait for language-specific parsing.
LanguageRegistry
Registry that provides language parsers and resolvers.
LanguageResolver
Trait for language-specific import/module resolution.

Functions

collect_type_refs_by_kind
Collect type references by walking the tree for nodes of a given kind and filtering out language-specific builtins.
config_files
detect_jvm_source_roots
Detect JVM source roots by checking for conventional directories. Used by both Java and Kotlin resolvers to find where source files live.
find_enclosing_symbol
Find the symbol that contains the given line number (innermost/smallest range).
first_line
node_text
parse_with_tree_sitter
Parse source code with a tree-sitter language and language-specific extractors.
parser_for
resolver_for
sibling_expansion
supported_extensions
symbol_from_node
Build an ExtractedSymbol from a tree-sitter node.