pub fn resolve_rust_use(
use_path: &str,
source_file: &str,
project_root: &Path,
) -> Option<PathBuf>Expand description
Resolve a Rust use path to a file path relative to the project root.
source_file is relative to project_root (e.g., “astmap-core/src/db/mod.rs”).
Returns an absolute path, or None for external crate imports.